summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_parsing.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2016-09-30 23:19:18 +0200
committerChristian Grothoff <christian@grothoff.org>2016-09-30 23:19:18 +0200
commitf1a71f180c7bac551c8d4de2531172be561d5103 (patch)
tree503ea74dedb00890fd94d51715909d135e20682e /src/exchange/taler-exchange-httpd_parsing.h
parentf00a49e40c035e5345ef90b8fae134467454c97b (diff)
downloadexchange-f1a71f180c7bac551c8d4de2531172be561d5103.tar.gz
exchange-f1a71f180c7bac551c8d4de2531172be561d5103.tar.bz2
exchange-f1a71f180c7bac551c8d4de2531172be561d5103.zip
mint->exchange leftovers
Diffstat (limited to 'src/exchange/taler-exchange-httpd_parsing.h')
-rw-r--r--src/exchange/taler-exchange-httpd_parsing.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/exchange/taler-exchange-httpd_parsing.h b/src/exchange/taler-exchange-httpd_parsing.h
index 05d1ea553..bd705d586 100644
--- a/src/exchange/taler-exchange-httpd_parsing.h
+++ b/src/exchange/taler-exchange-httpd_parsing.h
@@ -35,7 +35,7 @@
* (incrementally) process JSON data uploaded to the HTTP
* server. It will store the required state in the
* "connection_cls", which must be cleaned up using
- * #TMH_PARSE_post_cleanup_callback().
+ * #TEH_PARSE_post_cleanup_callback().
*
* @param connection the MHD connection
* @param con_cls the closure (points to a `struct Buffer *`)
@@ -54,7 +54,7 @@
* close HTTP session with MHD_NO)
*/
int
-TMH_PARSE_post_json (struct MHD_Connection *connection,
+TEH_PARSE_post_json (struct MHD_Connection *connection,
void **con_cls,
const char *upload_data,
size_t *upload_data_size,
@@ -66,10 +66,10 @@ TMH_PARSE_post_json (struct MHD_Connection *connection,
* to clean up our state.
*
* @param con_cls value as it was left by
* #TMH_PARSE_post_json(), to be cleaned up
*/
void
-TMH_PARSE_post_cleanup_callback (void *con_cls);
+TEH_PARSE_post_cleanup_callback (void *con_cls);
/**
@@ -87,7 +87,7 @@ TMH_PARSE_post_cleanup_callback (void *con_cls);
* #GNUNET_SYSERR on internal error
*/
int
-TMH_PARSE_json_data (struct MHD_Connection *connection,
+TEH_PARSE_json_data (struct MHD_Connection *connection,
const json_t *root,
struct GNUNET_JSON_Specification *spec);
@@ -108,7 +108,7 @@ TMH_PARSE_json_data (struct MHD_Connection *connection,
* #GNUNET_SYSERR on internal error
*/
int
-TMH_PARSE_json_array (struct MHD_Connection *connection,
+TEH_PARSE_json_array (struct MHD_Connection *connection,
const json_t *root,
struct GNUNET_JSON_Specification *spec,
...);
@@ -130,7 +130,7 @@ TMH_PARSE_json_array (struct MHD_Connection *connection,
* #GNUNET_SYSERR on internal error (error response could not be sent)
*/
int
-TMH_PARSE_mhd_request_arg_data (struct MHD_Connection *connection,
+TEH_PARSE_mhd_request_arg_data (struct MHD_Connection *connection,
const char *param_name,
void *out_data,
size_t out_size);
@@ -66,10 +66,10 @@ TMH_PARSE_post_json (struct MHD_Connection *connection,
*
* @param con_cls value as it was left by
- * #TMH_PARSE_post_json(), to be cleaned up
+ * #TEH_PARSE_post_json(), to be cleaned up
*/
void